@@ -1,5 +1,5 @@
 from dataclasses import dataclass
-from typing import ClassVar, Dict, List, Optional
+from typing import Callable, ClassVar, Dict, List, Optional
 
 from .specification import (
     Info,
@@ -18,6 +18,7 @@ class Options:
     :param info: Meta-information for the endpoint specification.
     :param default_security_scheme: Security scheme to apply to endpoints, unless overridden on a per-endpoint basis.
     :param extra_types: Extra types to list in the type catalog in addition to those found in operation signatures.
+    :param property_description_fun: Custom transformation function to apply to class property documentation strings.
     :param captions: User-defined captions for sections such as "Operations" or "Types".
     """
 
@@ -25,6 +26,7 @@ class Options:
     info: Info
     default_security_scheme: Optional[SecurityScheme] = None
     extra_types: Optional[List[type]] = None
+    property_description_fun: Callable[[type, str, str], str] = None
     captions: Dict[str, str] = None
 
     default_captions: ClassVar[Dict[str, str]] = {
